@@ -14,7 +14,10 @@
 		stop("number of states must be ",nbstate)
 	else {
 		for (i in 1:dim(seqdata)[2])
-			levels(seqdata[,i])[1:nbstate] <- value 
+			levels(seqdata[,i])[1:nbstate] <- value
+
+		if (all.equal(attr(seqdata,"alphabet"),attr(seqdata,"labels")))
+			attr(seqdata,"labels") <- value
 
 		attr(seqdata,"alphabet") <- value
 	}
