@@ -4,7 +4,7 @@
 
 seqeweight <- function(eseq, s) {
 
-  checkargs(alist(eseq = s))
+  TraMineR.check.depr.args(alist(eseq = s))
 
 	seqeweight.internal<-function(eseq){
 		if(is.eseq(eseq)) {
@@ -24,7 +24,7 @@ seqeweight <- function(eseq, s) {
 
 "seqeweight<-" <- function(eseq, s, value) {
 
-  checkargs(alist(eseq = s))
+  TraMineR.check.depr.args(alist(eseq = s))
 
 	if(!is.seqelist(eseq)) {
 		stop(" [!] eseq should be a seqelist. See help on seqecreate.")
@@ -38,7 +38,7 @@ seqeweight <- function(eseq, s) {
 
 seqeisweighted <- function(eseq, s) {
 
-  checkargs(alist(eseq = s))
+  TraMineR.check.depr.args(alist(eseq = s))
 
 	if(!is.seqelist(eseq)) {
 		stop(" [!] eseq should be a seqelist. See help on seqecreate.")
